//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Model/SampleModel.cpp
//! @brief     Implements class SampleModel
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2018
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Model/SampleModel.h"
#include "GUI/Model/Item/ItemWithMaterial.h"
#include "GUI/Model/Item/MultiLayerItem.h"
#include "GUI/Model/XML/Serializer.h"
#include <QApplication>

SampleModel::SampleModel() {}

QVector<MultiLayerItem*> SampleModel::multiLayerItems() const
{
    return m_multiLayers;
}

QVector<ItemWithMaterial*> SampleModel::itemsWithMaterial() const
{
    QVector<ItemWithMaterial*> result;

    for (auto* m : m_multiLayers)
        result << m->itemsWithMaterial();

    return result;
}

MultiLayerItem* SampleModel::addMultiLayer()
{
    m_multiLayers << new MultiLayerItem();
    return m_multiLayers.back();
}

void SampleModel::addMultiLayer(MultiLayerItem* multilayer)
{
    m_multiLayers << multilayer;
}

void SampleModel::removeMultiLayer(MultiLayerItem* item)
{
    m_multiLayers.removeAll(item);
}

QStringList SampleModel::multiLayerNames() const
{
    QStringList existingNames;
    for (const auto* item : m_multiLayers)
        existingNames << item->sampleName();
    return existingNames;
}

void SampleModel::serialize(Serializer& s)
{
    s.assertVersion(0);
    s.rw("Multilayers", m_multiLayers);
}
