//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Types/AxisProperty.h
//! @brief     Defines class AxisProperty
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2022
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#ifndef BORNAGAIN_GUI_MODEL_TYPES_AXISPROPERTY_H
#define BORNAGAIN_GUI_MODEL_TYPES_AXISPROPERTY_H


#include "Base/Axis/FixedBinAxis.h"
#include "GUI/Model/Types/DoubleProperty.h"
#include "GUI/Model/Types/UIntProperty.h"
#include <memory>

class Serializer;

// #baMigration docu
class AxisProperty {
public:
    UINT_PROPERTY(nbins, Nbins);
    DOUBLE_PROPERTY(min, Min);
    DOUBLE_PROPERTY(max, Max);

    void initNbins(const QString& label, const QString& tooltip, uint n = 100,
                   const variant<QString, Unit>& unit = "nbins");

    void initMin(const QString& label, const QString& tooltip, double value,
                 const variant<QString, Unit>& unit, uint decimals = 3,
                 const RealLimits& limits = RealLimits::nonnegative());
    void initMax(const QString& label, const QString& tooltip, double value,
                 const variant<QString, Unit>& unit, uint decimals = 3,
                 const RealLimits& limits = RealLimits::nonnegative());

    void serialize(Serializer& s);

    //! Creates an axis with empty title
    std::unique_ptr<FixedBinAxis> createAxis(double scaleFactor) const;
};

// #baMigration docu
#define AXIS_PROPERTY(nameLower)                                                                   \
protected:                                                                                         \
    AxisProperty m_##nameLower;                                                                    \
                                                                                                   \
public:                                                                                            \
    AxisProperty& nameLower() const { return *const_cast<AxisProperty*>(&m_##nameLower); }


#endif // BORNAGAIN_GUI_MODEL_TYPES_AXISPROPERTY_H
